<%@ page language="java" contentType="text/html; charset=UTF-8" pageEncoding="UTF-8"%>
<% request.setAttribute("contextPath", request.getContextPath()); %>
<!DOCTYPE html>
<html>
<head>
	<meta charset="UTF-8"/>
	<meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
	<title>DEXTUpload(NX+NJ) Samples</title>
	<link rel="stylesheet" href="${contextPath}/common/styles/default.css"/>
	<link rel="stylesheet" href="${contextPath}/common/js/prettify/tomorrow.css"/>
	<script src="${contextPath}/common/js/prettify/prettify.js"></script>
	<script src="${contextPath}/dextuploadnx/DEXTUploadNX.js"></script>
	<script>		
		window.onload = function () {
			prettyPrint();
			
			CreateDEXTUploadNX_Operator({
				ContainerID: "dextnx_container",
				ElementID: "dextnx",
				Operator_Type: "DOWNLOAD_MANAGER",
				NondirectiveDownload: true,
				ListViewSizeColumnWidth: 0,
				NXEventFunctions: {
					OnNXOperatorEventCreateComplete: function (id, optype) {
						NXOperators[id].AddDownloadItemFile("http://" + location.host + "/sample.nxnj/service/streamdownload.do?loop=1000", 1, "1000번루프돌린파일.txt", "", false);
						NXOperators[id].AddDownloadItemFile("http://" + location.host + "/sample.nxnj/service/streamdownload.do?loop=10000", 1, "10000번루프돌린파일.txt", "", true);
					},
					OnNXOperatorEventError: function (id, optype, err) {
						NXAlert(id, "컴포넌트ID:" + id + "\n오류메시지:\n" + err);
					},
					OnNXOperatorEventDownloadStartTotal: function (id, optype) {
						NXAlert(id, "다운로드를 시작합니다.");
					},
					OnNXOperatorEventDownloadCompleteTotal: function (id, optype) {					    
					    NXAlert(id, "다운로드가 완료되었습니다.");
					},
					OnNXOperatorEventDownloadCancelTotal: function (id, optype) {
						NXAlert(id, "다운로드가 중지되었습니다.");
					}
				}
			});
		};
		
		function downloadFiles() {
			NXOperators["dextnx"].DownloadStart();
		}
		
		function stopDownloading() {
			NXOperators["dextnx"].DownloadStop();
		}
	</script>
</head>
<body>
	<div id="Container">
		<header><div class="logobg"></div></header>
		<div id="root"><a href="${contextPath}">DEXTUpload<span class="f_point">(NX+NJ)</span> Samples</a> &gt; <a href="${contextPath}/#tlb-download">파일 다운로드</a> &gt; 예제 8</div>
		<div id="MainCenter">
			<article>	
				<div class="exTit">예제 8. 파일의 크기를 알 수 없을 때 다운로드 방법</div>	
				<dl>
					<dt>설명</dt>
					<dd>
						<p>DEXTUploadNX는 다운로드를 하는 경우 반드시 파일의 크기를 명시해주어야 합니다.</p>
						<p>파일의 크기가 있어야, 파일 다운로드하는 상태(진행률과 같은) 표시가 올바르게 처리됩니다.</p>
						<p>더불어 이어받기 기능을 처리하기 위해서는 정확한 파일의 크기를 요구합니다.</p>
						<p>&nbsp;</p>
						<p>일반적으로 다운로드할 대상이 정적인 파일인 경우가 대부분이지만, 간혹 서버단에서 런타임에 만들어진 파일을 다운로드할 경우도 있습니다.</p>
						<p>이런 경우에는 파일의 크기를 명확하게 파악하기 힘들기 때문에, DEXTUploadNX에서 다운로드할 파일을 등록할 때, 크기 값을 명시하기가 어렵습니다.</p>
						<p>DEXTUploadNX는 기본적으로 파일의 크기가 정확하지 않더라도 다운로드가 가능합니다.</p>
						<p>그러나 이어받기와 같은 부분에 문제가 발생할 수 있으므로 NondirectiveDownload 속성을 true로 설정하여 다운로드를 해야 합니다.</p>
						<p>대상 속성을 true로 설정하는 경우, 다른 설정과 상관없이 이어받기 기능을 사용하지 않도록 하고 있습니다.</p>
						<p>주의) 파일의 크기 정확하지 않으므로 이벤트나 타이머를 사용한 상태 정보를 제공하지 않도록 하는 것을 권합니다.</p>
						<pre class="prettyprint">
CreateDEXTUploadNX_Operator({
  ...
  // 이어받기를 사용하지 않도록 처리합니다.
  NondirectiveDownload: true,
  // 파일 크기 열이 불필요하므로 가로 길이를 0으로 설정합니다.
  ListViewSizeColumnWidth: 0,
  ...
  NXEventFunctions: {
    OnNXOperatorEventCreateComplete: function (id, optype) {
      // 파일의 크기를 나타내는 파라미터를 1로 입력합니다.
      NXOperators[id].AddDownloadItemFile(
        "http://~/sample.nxnj/service/streamdownload.do?loop=1000", 1, "1000번루프돌린파일.txt", "", false);
      NXOperators[id].AddDownloadItemFile(
        "http://~/sample.nxnj/service/streamdownload.do?loop=10000", 1, "10000번루프돌린파일.txt", "", true);
    },
    ...
  }
});</pre>
					</dd>		
					<dt>과정</dt>
					<dd>
						<div class="diagrambg">
							<div class="diagram-upload-flow">
								<a class="shape"><span class="head">Page</span><span class="target">download/example.do?index=0008</span><span class="comment">예제 화면</span></a>
								<a class="direction"><img src="${contextPath}/common/images/arrow01.gif" alt="화살표"/><span class="comment">GET</span></a>
								<a class="shape"><span class="head">FileServiceController</span><span class="target">service/streamdownload.do</span><span class="comment">다운로드 처리</span></a>
							</div>
						</div>
					</dd>					
					<dt>예제</dt>
					<dd>						
						<div id="dextnx_container" style="width:500px;height:300px;"></div>
						<p>&nbsp;</p> 
						<p>
							<input type="button" value="다운로드 시작" onclick="downloadFiles();"/>
							<input type="button" value="다운로드 중지" onclick="stopDownloading();"/>
						</p>
						<div id="out-state"></div>
					</dd>
				</dl>
			</article>
		</div>
	  <footer>
	    <div>Copyright ⓒ (주) 데브피아. All rights reserved.</div>
	  </footer>
	</div>
</body>
</html>