<%@ page language="java" contentType="text/html; charset=UTF-8" pageEncoding="UTF-8"%>
<% request.setAttribute("contextPath", request.getContextPath()); %>
<!DOCTYPE html>
<html>
<head>
	<meta charset="UTF-8"/>
	<meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
	<title>DEXTUpload(NX+NJ) Samples</title>
	<link rel="stylesheet" href="${contextPath}/common/styles/default.css"/>
	<link rel="stylesheet" href="${contextPath}/common/js/prettify/tomorrow.css"/>
	<script src="${contextPath}/common/js/prettify/prettify.js"></script>
	<script src="${contextPath}/dextuploadnx/DEXTUploadNX.js"></script>
	<script>
		var promptForAdding = true;
		
		window.onload = function () {
			prettyPrint();
			
			CreateDEXTUploadNX_Operator({
				ContainerID: "dextnx_container",
				ElementID: "dextnx",
				Operator_Type: "UPLOAD_MANAGER",
				EnableUploadHiddenFile: false,
				NXEventFunctions: {
					OnNXOperatorEventCreateComplete: function (id, optype) {
						NXAlert(id, "DEXTUploadNX가 로드되었습니다.");
					},
					OnNXOperatorEventError: function (id, optype, err) {
						NXAlert(id, "컴포넌트ID:" + id + "\n오류메시지:\n" + err);
					},
					OnNXOperatorEventPrevAddItem: function (id, optype, fileCount, folderCount, vFileCount) {
						var yn = NXConfirm(id, "파일 개수: " + fileCount + ", 폴더 개수: " + folderCount + ", 가상 파일 개수: " + vFileCount + "\n추가하시겠습니까?");
						return SetNXEventReturnValue(id, yn);
					},
					OnNXOperatorEventAddItem: function (id, optype, itemType, itemIndex) {						
						if (promptForAdding == true) {
							promptForAdding = NXConfirm(id, "형식: " + itemType + ", 순서: " + itemIndex + " 인 대상이 추가되고 있습니다.\n계속 보시겠습니까?");
						}
					},
					OnNXOperatorEventPostAddItem: function (id, optype, fileCount, folderCount, vFileCount) {
						for (var i = 0; i < encodedFiles.length; i++) {
							NXOperators[id].AddUpItemFile(encodedFiles[i]);
						}
						
						NXAlert(id, "파일 개수: " + fileCount + ", 폴더 개수: " + folderCount + ", 가상 파일 개수: " + vFileCount + "\n추가되었습니다.");
					},
					OnNXOperatorEventPrevDeleteItem: function (id, optype, fileCount, folderCount, vFileCount) {
						var yn = NXConfirm(id, "파일 개수: " + fileCount + ", 폴더 개수: " + folderCount + ", 가상 파일 개수: " + vFileCount + "\n삭제하시겠습니까?");
						return SetNXEventReturnValue(id, yn);
					},
					OnNXOperatorEventDeleteItem: function (id, optype, itemType, itemIndex) {
						if (promptForAdding == true) {
							promptForAdding = NXConfirm(id, "형식: " + itemType + ", 순서: " + itemIndex + " 인 대상이 삭제되고 있습니다.\n계속 보시겠습니까?");
						}
					},
					OnNXOperatorEventPostDeleteItem: function (id, optype, fileCount, folderCount, vFileCount) {
						NXAlert(id, "파일 개수: " + fileCount + ", 폴더 개수: " + folderCount + ", 가상 파일 개수: " + vFileCount + "\n삭제되었습니다.");
					}
				}
			});
		};
		
		function toggleDragNDrop(enable) {
			NXOperators["dextnx"].ListViewEnableDragDrop = enable;
		}
		
		function showFileDialog() {
			NXOperators["dextnx"].OpenFileDialog();
		}
		
		function showFolderDialog() {
			NXOperators["dextnx"].OpenFolderDialog();
		}
		
		function addFilePath(filePath) {
			if (filePath) {
				NXOperators["dextnx"].AddUpItemFile(filePath);
			}
		}
		
		function addFolderPath(folderPath) {
			if (folderPath) {
				NXOperators["dextnx"].AddUpItemFolder(folderPath);
			}
		}
		
		function deleteFileByIndex(index) {
			if (isNaN(index)) {
				alert("삭제할 파일의 인덱스(0부터 시작)를 입력하세요.");
			} else {
				NXOperators["dextnx"].DeleteItem(parseInt(index));
			}
		}
		
		function deleteSelectedFile() {
			NXOperators["dextnx"].DeleteSelectedItems();
		}
		
		function deleteAll() {
			NXOperators["dextnx"].DeleteAllItems();
		}
	</script>
</head>
<body>
	<div id="Container">
		<header><div class="logobg"></div></header>
		<div id="root"><a href="${contextPath}">DEXTUpload<span class="f_point">(NX+NJ)</span> Samples</a> &gt; <a href="${contextPath}/#tlb-upload">파일 업로드</a> &gt; 예제 2</div>
		<div id="MainCenter">
			<article>	
				<div class="exTit">예제 2. 업로드 아이템 추가/삭제</div>	
				<dl>
					<dt>설명</dt>
					<dd>
						<p>DEXTUploadNX 컴포넌트의 업로드 매니저(Manager) 객체에  업로드할 파일을 추가하거나 삭제하는 방법을 설명하는 예제입니다.</p>
						<p>업로드 매니저에서 파일을 추가하거나 삭제하기 위해서 여러가지 속성 및 메소드를 제공합니다.</p>
						<pre class="prettyprint">
// 업로드하고자 하는 사용자 PC의 로컬 파일 경로를 직접 등록합니다.						
dextnxObj.AddUpItemFile(로컬 파일 경로);

// 업로드하고자 하는 사용자 PC의 로컬 폴더 경로를 직접 등록합니다.						
dextnxObj.AddUpItemFolder(로컬 폴더 경로);

// 파일 선택 다이얼로그 창을 사용하여 파일을 등록하도록 합니다.
dextnxObj.OpenFileDialog();

// 폴더 선택 다이얼로그 창을 사용하여 파일을 등록하도록 합니다.
dextnxObj.OpenFolderDialog();

// 드래그&amp;드롭으로 파일을 등록할 수 있도록 설정합니다.
dextnxObj.ListViewEnableDragDrop = true;

CreateDEXTUploadNX_Operator({
  ...
  // 폴더를 추가할 때, 숨김 파일을 포함하지 않으려 한다면 
  // CreateDEXTUploadNX_Operator 함수에서 EnableUploadHiddenFile 속성을 false로 설정합니다.
  EnableUploadHiddenFile: false,
  NXEventFunctions: {
    ...
  }
});

// index 순서(0부터 시작)에 해당하는 파일을 삭제합니다.
dextnxObj.DeleteItem(index);

// 선택된 파일을 삭제합니다.
// 리스트 화면에서 shift, ctrl 키를 사용하여 여러 파일을 선택할 수 있습니다.
dextnxObj.DeleteSelectedItems();

// 모든 파일을 삭제합니다.
dextnxObj.DeleteAllItems();
</pre>
						<p>업로드 매니저는 파일 추가 되거나 파일이 삭제가 될 때, 이벤트가 발생합니다.</p>
						<pre class="prettyprint">
CreateDEXTUploadNX_Operator({
  ...
  NXEventFunctions: {
    ...
    OnNXOperatorEventPrevAddItem: function (id, optype, fileCount, folderCount, vFileCount) {
      // 파일이 추가되기 전에 호출됩니다.
    },
    OnNXOperatorEventAddItem: function (id, optype, itemType, itemIndex) {
      // 파일이 추가될 때 호출됩니다. (추가되는 개수만큼 호출됩니다.)
    },
    OnNXOperatorEventPostAddItem: function (id, optype, fileCount, folderCount, vFileCount) {
      // 파일 추가가 완료되면 호출됩니다.
    },
    OnNXOperatorEventPrevDeleteItem: function (id, optype, fileCount, folderCount, vFileCount) {
      // 파일이 삭제되기 전에 호출됩니다.
    },
    OnNXOperatorEventDeleteItem: function (id, optype, itemType, itemIndex) {
      // 파일이 삭제될 때 호출됩니다. (삭제되는 개수만큼 호출됩니다.)
    },
    OnNXOperatorEventPostDeleteItem: function (id, optype, fileCount, folderCount, vFileCount) {
      // 파일 삭제가 완료되면 호출됩니다.
    },
    ...
  }
});</pre>
					</dd>					
					<dt>예제</dt>
					<dd>						
						<div id="dextnx_container" style="width:500px;height:300px;"></div>
						<p>Drag &amp; Drop 활성화</p>
						<p>
							<input type="radio" name="rdoDnd" onclick="toggleDragNDrop(true);" checked="checked"/><label>사용</label>
							<input type="radio" name="rdoDnd" onclick="toggleDragNDrop(false);"/><label>사용 안함</label>
						</p>
						<p>&nbsp;</p> 
						<p>다이얼로그 창을 이용한 파일 또는 폴더 추가</p>
						<p>
							<input type="button" value="파일 다이얼로그" onclick="showFileDialog();"/>
							<input type="button" value="폴더 다이얼로그" onclick="showFolderDialog();"/>
						</p>
						<p>&nbsp;</p> 
						<p>경로를 직접 입력하여 파일 또는 폴더 추가</p>
						<p>
							<input type="text" value="ex) c:\temp\abc.txt" id="txtFilePath"/>
							<input type="button" value="파일 경로 추가" onclick="addFilePath(document.getElementById('txtFilePath').value);"/>
						</p>
						<p>
							<input type="text" value="ex) c:\temp" id="txtFolderPath"/>
							<input type="button" value="폴더 경로 추가" onclick="addFolderPath(document.getElementById('txtFolderPath').value);"/>
						</p>
						<p>&nbsp;</p> 
						<p>파일 삭제</p>
						<p>
							<input type="text" value="0" id="txtFileIndex"/>
							<input type="button" value="파일 삭제(index)" onclick="deleteFileByIndex(document.getElementById('txtFileIndex').value);"/>
							<input type="button" value="선택된 파일 삭제" onclick="deleteSelectedFile();"/>
							<input type="button" value="모든 파일 삭제" onclick="deleteAll();"/>
						</p>
					</dd>
				</dl>
			</article>
		</div>
	  <footer>
	    <div>Copyright ⓒ (주) 데브피아. All rights reserved.</div>
	  </footer>
	</div>
</body>
</html>