<%@ page language="java" contentType="text/html; charset=UTF-8" pageEncoding="UTF-8"%>
<% request.setAttribute("contextPath", request.getContextPath()); %>
<!DOCTYPE html>
<html>
<head>
	<meta charset="UTF-8"/>
	<meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
	<title>DEXTUpload(NX+NJ) Samples</title>
	<link rel="stylesheet" href="${contextPath}/common/styles/default.css"/>
	<link rel="stylesheet" href="${contextPath}/common/js/prettify/tomorrow.css"/>
	<script src="${contextPath}/common/js/prettify/prettify.js"></script>
	<script src="${contextPath}/dextuploadnx/DEXTUploadNX.js"></script>
	<script>
		var promptForAdding = true;
		
		window.onload = function () {
			prettyPrint();
			
			CreateDEXTUploadNX_Operator({
				ContainerID: "dextnx_container",
				ElementID: "dextnx",
				Operator_Type: "UPLOAD_MANAGER",
				NXEventFunctions: {
					OnNXOperatorEventError: function (id, optype, err) {
						NXAlert(id, "컴포넌트ID:" + id + "\n오류메시지:\n" + err);
					},
					OnNXOperatorEventCreateComplete: function (id, optype) {
						NXAlert(id, "DEXTUploadNX가 로드되었습니다.");
					},
					OnNXOperatorEventUploadStartTotal: function (id, optype) {
						NXAlert(id, "업로드를 시작합니다.");
					},
					OnNXOperatorEventUploadCompleteTotal: function (id, optype) {
					    var resObj = NXOperators[id].Responses;
					    var responseData = "";
					    for (var i = 0; i < resObj.Count; i++) {
					        responseData += (i == 0) ? resObj.Item(i) : "\n" + resObj.Item(i);
					    }
					    
					    NXAlert(id, "업로드가 완료되었습니다.\n\n서버로부터 받은 응답 데이터\n" + responseData);
					},
					OnNXOperatorEventUploadCancel: function (id, optype) {
						NXAlert(id, "업로드가 중지되었습니다.");
					}
				}
			});
		};
		
		function showFileDialog() {
			NXOperators["dextnx"].OpenFileDialog();
		}
		
		function showFolderDialog() {
			NXOperators["dextnx"].OpenFolderDialog();
		}
		
		function uploadFiles() {
			NXOperators["dextnx"].UploadURL = "http://" + location.host + "/sample.nxnj/service/simpleupload.do";
			NXOperators["dextnx"].UploadStart();
		}
		
		function stopUploading() {
			NXOperators["dextnx"].UploadStop();
		}
	</script>
</head>
<body>
	<div id="Container">
		<header><div class="logobg"></div></header>
		<div id="root"><a href="${contextPath}">DEXTUpload<span class="f_point">(NX+NJ)</span> Samples</a> &gt; <a href="${contextPath}/#tlb-upload">파일 업로드</a> &gt; 예제 3</div>
		<div id="MainCenter">
			<article>	
				<div class="exTit">예제 3. 단순 업로드</div>
				<dl>
					<dt>설명</dt>
					<dd>
						<p>파일을 업로드하는 가장 단순한 예제입니다.</p>
						<p>DEXTUploadNX에서 파일을 업로드 하기 위해서는 업로드를 처리할 경로를 설정하고 업로드를 시작하는 메소드를 호출하면 됩니다.</p>
						<pre class="prettyprint">
// 파일 업로드를 처리할 경로를 절대경로(필수)로 설정합니다.
dextnxObj.UploadURL = "업로드를 처리할 서버(백엔드) 측 경로";

// 파일 업로드를 시작합니다.
dextnxObj.UploadStart();

// 파일 업로드를 중단합니다.
dextnxObj.UploadStop();</pre>
						<pre class="prettyprint">
CreateDEXTUploadNX_Operator({
  ...
  NXEventFunctions: {
    OnNXOperatorEventUploadStartTotal: function (id, optype) {
      // 업로드가 시작할 때 호출됩니다.
    },
    OnNXOperatorEventUploadCompleteTotal: function (id, optype) {
      // 업로드가 완료되면 호출됩니다.
    },
    OnNXOperatorEventUploadCancel: function (id, optype) {
      // 업로드가 중단되면 호출됩니다.
    },
    ...
  }
});</pre>
						<p>다음은 서버 측 코드에서 데이터를 처리하는 방법입니다.</p>   
						<pre class="prettyprint">
// nx 변수는 DEXTUploadNXRequest 클래스의 객체입니다.
// DEXTUploadNXRequest 클래스는 제품 라이브러리에 포함된 클래스가 아닙니다.
// Spring은 모델 바인딩 기능을 가지고 있으므로 DEXTUploadNX로부터 전달되는 폼 정보를 다루기 편하도록
// 제공된 예시 클래스입니다.

// DEXTUploadNX는 'DEXTUploadNX' 이름으로 각 파일 데이터를 서버로 전달합니다.
// DEXTUploadNXRequest 객체의 getFiles 메소드로부터 파일 정보를 얻습니다.
for (MultipartFile file : nx.getFiles()) {
  item = (FileItem)file;
  // 파일이 0바이트 파일이 아닌 경우 파일을 저장합니다.
  if (item.isEligibleFile()) {
    // dextnj-servlet.xml에 defaultRepository 속성에 정의된 위치로 파일을 저장합니다.
    // 동일한 파일명의 파일이 있다면 suffix가 따로 붙습니다. 
    item.save();
  }
}</pre>
					</dd>
					<dt>과정</dt>
					<dd>
						<div class="diagrambg">
							<div class="diagram-upload-flow">
								<a class="shape"><span class="head">Page</span><span class="target">upload/example.do?index=0003</span><span class="comment">예제 화면</span></a>
								<a class="direction"><img src="${contextPath}/common/images/arrow01.gif" alt="화살표"/><span class="comment">Post</span></a>					
								<a class="shape"><span class="head">FileServiceController</span><span class="target">service/simpleupload.do</span><span class="comment">전송 처리</span></a>
							</div>
						</div>
					</dd>			
					<dt>예제</dt>
					<dd>						
						<div id="dextnx_container" style="width:500px;height:300px;"></div>
						<p>&nbsp;</p>
						<p>
							<input type="button" value="파일 다이얼로그" onclick="showFileDialog();"/>
							<input type="button" value="폴더 다이얼로그" onclick="showFolderDialog();"/>
						</p>
						<p>&nbsp;</p>
						<p>백엔드 제한: 개별 파일이 300MB가 넘거나, 전체 파일의 크기가 500MB가 넘는다면 업로드가 실패(오류발생)합니다.</p>
						<p>백엔드 제한: jpg,gif,png,doc,xls,ppt,docx,xlsx,pptx,pdf,txt,zip,7z,hwp  만 허용합니다.</p>
						<p>
							<input type="button" value="업로드 시작" onclick="uploadFiles();"/>
							<input type="button" value="업로드 중지" onclick="stopUploading();"/>
						</p>
					</dd>
				</dl>
			</article>
		</div>
	  <footer>
	    <div>Copyright ⓒ (주) 데브피아. All rights reserved.</div>
	  </footer>
	</div>
</body>
</html>