<%@ page language="java" contentType="text/html; charset=UTF-8" pageEncoding="UTF-8"%>
<% request.setAttribute("contextPath", request.getContextPath()); %>
<!DOCTYPE html>
<html>
<head>
	<meta charset="UTF-8"/>
	<meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
	<title>DEXTUpload(NX+NJ) Samples</title>
	<link rel="stylesheet" href="${contextPath}/common/styles/default.css"/>
	<link rel="stylesheet" href="${contextPath}/common/js/prettify/tomorrow.css"/>
	<script src="${contextPath}/common/js/prettify/prettify.js"></script>
	<script src="${contextPath}/dextuploadnx/DEXTUploadNX.js"></script>
	<script>
		var promptForAdding = true;
		
		window.onload = function () {
			prettyPrint();
			
			CreateDEXTUploadNX_Operator({
				ContainerID: "dextnx_container",
				ElementID: "dextnx",
				Operator_Type: "UPLOAD_MANAGER",
				ListViewShowOnlyTitle: false,
				EnableUploadHiddenFile: false,
				EnableUploadEmptyFolder: true,
				NXEventFunctions: {
					OnNXOperatorEventError: function (id, optype, err) {
						NXAlert(id, "컴포넌트ID:" + id + "\n오류메시지:\n" + err);
					},
					OnNXOperatorEventCreateComplete: function (id, optype) {
						NXAlert(id, "DEXTUploadNX가 로드되었습니다.");
					},
					OnNXOperatorEventUploadStartTotal: function (id, optype) {
						NXAlert(id, "업로드를 시작합니다.");
					},
					OnNXOperatorEventUploadCompleteTotal: function (id, optype) {
					    var resObj = NXOperators[id].Responses;
					    var responseData = "";
					    for (var i = 0; i < resObj.Count; i++) {
					        responseData += (i == 0) ? resObj.Item(i) : "\n" + resObj.Item(i);
					    }
					    
					    NXAlert(id, "업로드가 완료되었습니다.\n\n서버로부터 받은 응답 데이터\n" + responseData);
					},
					OnNXOperatorEventUploadCancel: function (id, optype) {
						NXAlert(id, "업로드가 중지되었습니다.");
					}
				}
			});
		};
		
		function showFolderDialog() {
			NXOperators["dextnx"].OpenFolderDialog();
		}
		
		function uploadFiles() {
			NXOperators["dextnx"].UploadURL = "http://" + location.host + "/sample.nxnj/service/folderupload.do";
			NXOperators["dextnx"].UploadStart();
		}
		
		function stopUploading() {
			NXOperators["dextnx"].UploadStop();
		}
	</script>
</head>
<body>
	<div id="Container">
		<header><div class="logobg"></div></header>
		<div id="root"><a href="${contextPath}">DEXTUpload<span class="f_point">(NX+NJ)</span> Samples</a> &gt; <a href="${contextPath}/#tlb-upload">파일 업로드</a> &gt; 예제 6</div>
		<div id="MainCenter">
			<article>	
				<div class="exTit">예제 6. 비어있는 폴더 업로드(생성)</div>
				<dl>
					<dt>설명</dt>
					<dd>
						<p>폴더로 등록을 하는 경우 업로드를 하게 되면 파일이 포함되지 않는 폴더 정보는 서버로 전달되지 않습니다.</p>
						<p>EnableUploadEmptyFolder 속성을 true로 설정하면 비어있는 폴더만 따로 전달이 됩니다.</p>
						<pre class="prettyprint">
CreateDEXTUploadNX_Operator({
  ...
  // 파일 경로가 모두 보이도록 설정합니다.
  ListViewShowOnlyTitle: false,
  // 폴더 다이얼로그로 폴더를 등록하는 경우, 숨김 파일도 함께 전달이 되므로 의도치 않은 파일이 전송될 수 있습니다.
  // EnableUploadHiddenFile 속성을 false로 지정하면 숨김 파일을 대상에서 제외됩니다.
  EnableUploadHiddenFile: false,
  // 파일이 없는 폴더를 업로드 시점에 전달하기 위해서 EnableUploadEmptyFolder 속성을 true로 지정합니다.
  EnableUploadEmptyFolder: true,
  NXEventFunctions: {
    ...
  }
});</pre>
						<p>다음은 서버 측 코드에서 데이터를 처리하는 방법입니다.</p>   
						<pre class="prettyprint">
for (int i = 0; i &lt; nx.getFiles().size(); i++) {
  // DEXTUploadNX는 'DEXTUploadNX_FolderPath' 이름으로 각 파일의 경로를 서버로 전달합니다.
  // DEXTUploadNXRequest 객체의 getFolderPathes 메소드로부터 정보를 얻습니다.
  
  // 루트 경로부터 상대 경로를 생성합니다.
  dir = new File(root, nx.getFolderPathes().get(i).replace("\\", File.separator));
  if (!dir.exists()) {
    dir.mkdir();
  }

  item = (FileItem)nx.getFiles().get(i);

  if (item.isEligibleFile()) {
    item.save(dir.getAbsolutePath());
  }
}

// DEXTUploadNX는 'DEXTUploadNX_EmptyFolderPath' 이름으로 비어있는 폴더 정보를 서버로 전달합니다.
// DEXTUploadNXRequest 객체의 getEmptyFolderPathes 메소드로부터 정보를 얻습니다.
for (String path : nx.getEmptyFolderPathes()) {
  // 파일이 없는 폴더의 경로를 가지고 옵니다.
  // 루트 경로부터 상대 경로를 생성합니다.
  dir = new File(root, path.replace("\\", File.separator));
  if (!dir.exists()) {
    dir.mkdir();
  }
}</pre>
					</dd>
					<dt>과정</dt>
					<dd>
						<div class="diagrambg">
							<div class="diagram-upload-flow">
								<a class="shape"><span class="head">Page</span><span class="target">upload/example.do?index=0006</span><span class="comment">예제 화면</span></a>
								<a class="direction"><img src="${contextPath}/common/images/arrow01.gif" alt="화살표"/><span class="comment">Post</span></a>					
								<a class="shape"><span class="head">FileServiceController</span><span class="target">service/folderupload.do</span><span class="comment">전송 처리</span></a>
							</div>
						</div>
					</dd>			
					<dt>예제</dt>
					<dd>						
						<div id="dextnx_container" style="width:500px;height:300px;"></div>
						<p>&nbsp;</p>
						<p>
							<input type="button" value="폴더 다이얼로그" onclick="showFolderDialog();"/>
						</p>
						<p>&nbsp;</p>
						<p>백엔드 제한: 개별 파일이 300MB가 넘거나, 전체 파일의 크기가 500MB가 넘는다면 업로드가 실패(오류발생)합니다.</p>
						<p>백엔드 제한: jpg,gif,png,doc,xls,ppt,docx,xlsx,pptx,pdf,txt,zip,7z,hwp  만 허용합니다.</p>
						<p>
							<input type="button" value="업로드 시작" onclick="uploadFiles();"/>
							<input type="button" value="업로드 중지" onclick="stopUploading();"/>
						</p>
					</dd>
				</dl>
			</article>
		</div>
	  <footer>
	    <div>Copyright ⓒ (주) 데브피아. All rights reserved.</div>
	  </footer>
	</div>
</body>
</html>