<%@ page language="java" contentType="text/html; charset=UTF-8" pageEncoding="UTF-8"%>
<% request.setAttribute("contextPath", request.getContextPath()); %>
<!DOCTYPE html>
<html>
<head>
	<meta charset="UTF-8"/>
	<meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
	<title>DEXTUpload(NX+NJ) Samples</title>
	<link rel="stylesheet" href="${contextPath}/common/styles/default.css"/>
	<link rel="stylesheet" href="${contextPath}/common/js/prettify/tomorrow.css"/>
	<script src="${contextPath}/common/js/prettify/prettify.js"></script>
	<script src="${contextPath}/dextuploadnx/DEXTUploadNX.js"></script>
	<script>
		var promptForAdding = true;
		
		window.onload = function () {
			prettyPrint();
			
			CreateDEXTUploadNX_Operator({
				ContainerID: "dextnx_container",
				ElementID: "dextnx",
				Operator_Type: "UPLOAD_MANAGER",				
				NXEventFunctions: {
					OnNXOperatorEventError: function (id, optype, err) {
						NXAlert(id, "컴포넌트ID:" + id + "\n오류메시지:\n" + err);
					},
					OnNXOperatorEventCreateComplete: function (id, optype) {
						NXAlert(id, "DEXTUploadNX가 로드되었습니다.");
					},
					OnNXOperatorEventUploadStartTotal: function (id, optype) {
						NXAlert(id, "업로드를 시작합니다.");
					},
					OnNXOperatorEventUploadCompleteTotal: function (id, optype) {
					    var resObj = NXOperators[id].Responses;
					    var responseData = "";
					    for (var i = 0; i < resObj.Count; i++) {
					        responseData += (i == 0) ? resObj.Item(i) : "\n" + resObj.Item(i);
					    }
					    
					    NXAlert(id, "업로드가 완료되었습니다.\n\n서버로부터 받은 응답 데이터\n" + responseData);
					},
					OnNXOperatorEventUploadCancel: function (id, optype) {
						NXAlert(id, "업로드가 중지되었습니다.");
					}
				}
			});
		};
		
		function showFileDialog() {
			NXOperators["dextnx"].OpenFileDialog();
		}
		
		function uploadFiles() {
			NXOperators["dextnx"].UploadURL = "http://" + location.host + "/sample.nxnj/service/userdataupload.do";
			NXOperators["dextnx"].UploadStart();
		}
		
		function stopUploading() {
			NXOperators["dextnx"].UploadStop();
		}
		
		function addUserData() {
			var index = document.getElementById("txtFileIndex").value;
			var name = document.getElementById("txtUserDataName").value;
			var value = document.getElementById("txtUserDataValue").value;
			
			if (!index || isNaN(index)) {
				alert("파일의 인덱스(0부터 시작)를 올바르게 입력하세요.");
			} else if (!name) {
				alert("사용자 데이터 이름을 올바르게 입력하세요.");
			} else {
				NXOperators["dextnx"].AddUpItemFileUserData(parseInt(index), name, value);
				document.getElementById("txtFileIndex").value = "";
				document.getElementById("txtUserDataName").value = "";
				document.getElementById("txtUserDataValue").value = "";
			}
		}
		
		function showUserData() {
			var size = NXOperators["dextnx"].UpItems.Count;
			var strSplit = NXOperators["dextnx"].DEXTNX_Split_Str;
			var strEmpty = NXOperators["dextnx"].DEXTNX_Empty_Str;
			var userData = "";
			
			for (var i = 0; i < size; i++) {
				if (NXOperators["dextnx"].IsSelectedItem(i) == true) {
					var item = NXOperators["dextnx"].Item(i);
					var tokens = item.FileUserDatas.split(strSplit);
					
					for (var j = 0; j < tokens.length - 1; j+=2) {
						if (j < (tokens.length - 1) && tokens[j + 1] == strEmpty)
							userData += tokens[j] + "=\n";
						else
							userData += tokens[j] + "=" + tokens[j + 1] + "\n";
					}
					
					alert(userData);
					
					return;
				}
			}
			
			alert("파일이 없거나 선택된 항목이 없습니다.");
		}
		
		function deleteUserData() {
			var index = document.getElementById("txtDeleteFileIndex").value;
			var name = document.getElementById("txtDeleteUserDataName").value;
			
			if (!index || isNaN(index)) {
				alert("파일의 인덱스(0부터 시작)를 올바르게 입력하세요.");
			} else if (!name) {
				alert("사용자 데이터 이름을 올바르게 입력하세요.");
			} else {
				NXOperators["dextnx"].DeleteUpItemFileUserData(parseInt(index), name);
				document.getElementById("txtDeleteFileIndex").value = "";
				document.getElementById("txtDeleteUserDataName").value = "";
			}
		}
	</script>
</head>
<body>
	<div id="Container">
		<header><div class="logobg"></div></header>
		<div id="root"><a href="${contextPath}">DEXTUpload<span class="f_point">(NX+NJ)</span> Samples</a> &gt; <a href="${contextPath}/#tlb-upload">파일 업로드</a> &gt; 예제 7</div>
		<div id="MainCenter">
			<article>	
				<div class="exTit">예제 7. 파일의 메타데이터 추가/삭제</div>
				<dl>
					<dt>설명</dt>
					<dd>
						<p>업로드 되는 파일마다 key = value 형식의 값의 집합을 실어 보낼 수 있습니다.</p>
						<p>이 파일마다 함께 보내지는 데이터를 User Data라고 합니다.</p>
						<p>이 User Data는 실제로 키[구분자]값[구분자]키[구분자]값[구분자] 형식으로 전달됩니다.</p>
						<pre class="prettyprint">
// 업로드할 파일의 순서에 '키'와 '값'을 설정합니다.
dextnxObj.AddUpItemFileUserData(파일인덱스값, 키, 값);

// 동일한 파일에 User Data를 여러번 등록하는 경우
// 1번 파일의 User Data는 다음과 같은 설정됩니다.
// a[SPLIT]123[SPLIT]b[SPLIT][EMPTY]c[SPLIT]QWE[SPLIT]
dextnxObj.AddUpItemFileUserData(1, "a", "123");
dextnxObj.AddUpItemFileUserData(1, "b", "");
dextnxObj.AddUpItemFileUserData(1, "c", "QWE");

// User 데이터를 삭제하려면
dextnxObj.DeleteUpItemFileUserData(파일인덱스값, 키);

// 이렇게 등록된 User Data를 스크립트 상에서 확인하려면 
var item = dextnxObj.Item(i);
var userdata = item.FileUserDatas;</pre> 
						<p>다음은 서버 측 코드에서 데이터를 처리하는 방법입니다.</p>   
						<pre class="prettyprint">
for (int i = 0; i &lt; nx.getFiles().size(); i++) {
  // DEXTUploadNX는 'DEXTUploadNX_UserData' 이름으로 각 파일의 User Data를 서버로 전달합니다.
  // DEXTUploadNXRequest 객체의 getUserData 메소드로부터 정보를 얻습니다.
  usedata = nx.getUserData().get(i);
}</pre>
					</dd>
					<dt>과정</dt>
					<dd>
						<div class="diagrambg">
							<div class="diagram-upload-flow">
								<a class="shape"><span class="head">Page</span><span class="target">upload/example.do?index=0007</span><span class="comment">예제 화면</span></a>
								<a class="direction"><img src="${contextPath}/common/images/arrow01.gif" alt="화살표"/><span class="comment">Post</span></a>					
								<a class="shape"><span class="head">FileServiceController</span><span class="target">service/userdataupload.do</span><span class="comment">전송 처리</span></a>
							</div>
						</div>
					</dd>			
					<dt>예제</dt>
					<dd>						
						<div id="dextnx_container" style="width:500px;height:300px;"></div>
						<p>&nbsp;</p>
						<p>파일 먼저 추가한 후 사용자 데이터를 추가/삭제하셔야 합니다.</p>
						<p>
							<input type="button" value="파일 다이얼로그" onclick="showFileDialog();"/>
						</p>
						<p>&nbsp;</p>
						<p>주어진 순서에 해당하는 파일의 사용자 데이터(이름=값)를 추가합니다.</p>
						<p>
							파일 인덱스: <input type="text" id="txtFileIndex"/>
							사용자 데이터 이름: <input type="text" id="txtUserDataName"/>
							사용자 데이터 값: <input type="text" id="txtUserDataValue"/>
							<input type="button" value="사용자 데이터 추가" onclick="addUserData();"/>
						</p>
						<p>&nbsp;</p>
						<p>파일 리스트에서 현재 선택된 파일의 사용자 데이터 확인합니다.</p>
						<p>
							<input type="button" value="선택된 파일의 사용자 데이터 확인" onclick="showUserData();"/>
						</p>
						<p>&nbsp;</p>
						<p>주어진 순서에 해당하는 사용자 데이터(이름=값)를 삭제합니다.</p>
						<p>
							파일 인덱스: <input type="text" id="txtDeleteFileIndex"/>
							사용자 데이터 이름: <input type="text" id="txtDeleteUserDataName"/>
							<input type="button" value="사용자 데이터 삭제" onclick="deleteUserData();"/>
						</p>
						<p>&nbsp;</p>
						<p>백엔드 제한: 개별 파일이 300MB가 넘거나, 전체 파일의 크기가 500MB가 넘는다면 업로드가 실패(오류발생)합니다.</p>
						<p>백엔드 제한: jpg,gif,png,doc,xls,ppt,docx,xlsx,pptx,pdf,txt,zip,7z,hwp  만 허용합니다.</p>
						<p>
							<input type="button" value="업로드 시작" onclick="uploadFiles();"/>
							<input type="button" value="업로드 중지" onclick="stopUploading();"/>
						</p>
					</dd>
				</dl>
			</article>
		</div>
	  <footer>
	    <div>Copyright ⓒ (주) 데브피아. All rights reserved.</div>
	  </footer>
	</div>
</body>
</html>