<%@ page language="java" contentType="text/html; charset=UTF-8" pageEncoding="UTF-8"%>
<% request.setAttribute("contextPath", request.getContextPath()); %>
<!DOCTYPE html>
<html>
<head>
	<meta charset="UTF-8"/>
	<meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
	<title>DEXTUpload(NX+NJ) Samples</title>
	<link rel="stylesheet" href="${contextPath}/common/styles/default.css"/>
	<link rel="stylesheet" href="${contextPath}/common/js/prettify/tomorrow.css"/>
	<script src="${contextPath}/common/js/prettify/prettify.js"></script>
	<script src="${contextPath}/dextuploadnx/DEXTUploadNX.js"></script>
	<script>
		var promptForAdding = true;
		
		window.onload = function () {
			prettyPrint();
			
			CreateDEXTUploadNX_Operator({
				ContainerID: "dextnx_container",
				ElementID: "dextnx",
				Operator_Type: "UPLOAD_MANAGER",	
				EnableUploadFilesNotExist: true,
				NXEventFunctions: {
					OnNXOperatorEventError: function (id, optype, err) {
						NXAlert(id, "컴포넌트ID:" + id + "\n오류메시지:\n" + err);
					},
					OnNXOperatorEventCreateComplete: function (id, optype) {
						NXAlert(id, "DEXTUploadNX가 로드되었습니다.");
					},
					OnNXOperatorEventUploadStartTotal: function (id, optype) {
						NXAlert(id, "업로드를 시작합니다.");
					},
					OnNXOperatorEventUploadCompleteTotal: function (id, optype) {
					    var resObj = NXOperators[id].Responses;
					    var responseData = "";
					    for (var i = 0; i < resObj.Count; i++) {
					        responseData += (i == 0) ? resObj.Item(i) : "\n" + resObj.Item(i);
					    }
					    
					    NXAlert(id, "업로드가 완료되었습니다.\n\n서버로부터 받은 응답 데이터\n" + responseData);
					},
					OnNXOperatorEventUploadCancel: function (id, optype) {
						NXAlert(id, "업로드가 중지되었습니다.");
					}
				}
			});
		};
		
		function showFileDialog() {
			NXOperators["dextnx"].OpenFileDialog();
		}
		
		function uploadFiles() {
			NXOperators["dextnx"].UploadURL = "http://" + location.host + "/sample.nxnj/service/formupload.do";
			NXOperators["dextnx"].UploadStart();
		}
		
		function stopUploading() {
			NXOperators["dextnx"].UploadStop();
		}
		
		function addUserForm() {
			var name = document.getElementById("txtUserFormName").value;
			var value = document.getElementById("txtUserFormValue").value;
			
			if (!name) {
				alert("사용자 폼 이름을 올바르게 입력하세요.");
			} else {
				NXOperators["dextnx"].AddUpItemUserForm(name, value);
				document.getElementById("txtUserFormName").value = "";
				document.getElementById("txtUserFormValue").value = "";
			}
		}
		
		function showAllUserForms() {
			var size = NXOperators["dextnx"].UpItems.Count;
			var item = null;
			var userForms = "";
			
			for (var i = 0; i < size; i++) {
				item = NXOperators["dextnx"].UpItems.GetIndexItem(i);
				if (item.ItemType == "USER_FORM") {
					userForms += item.FormName + "=" + item.FormValue + "\n";
				}
			}
			
			if (userForms) {
				alert(userForms);
			} else {			
				alert("사용자 폼이 없습니다.");
			}
		}
		
		function getUserFormValue() {
			var name = document.getElementById("txtGetUserFormName").value;
			if (!name) {
				alert("사용자 폼 이름을 올바르게 입력하세요.");
			} else {
				var uform = NXOperators["dextnx"].Form(name);
				if (uform) {
					alert(uform.FormValue);
					document.getElementById("txtGetUserFormName").value = "";
				} else {
					alert(name + "에 해당하는 사용자 폼이 없습니다.");
				}
			}
		}
		
		function deleteUserForm() {
			var name = document.getElementById("txtDeleteUserFormName").value;
			
			if (!name) {
				alert("사용자 데이터 이름을 올바르게 입력하세요.");
			} else {
				NXOperators["dextnx"].DeleteFormItem(name);
				document.getElementById("txtDeleteUserFormName").value = "";
			}
		}
	</script>
</head>
<body>
	<div id="Container">
		<header><div class="logobg"></div></header>
		<div id="root"><a href="${contextPath}">DEXTUpload<span class="f_point">(NX+NJ)</span> Samples</a> &gt; <a href="${contextPath}/#tlb-upload">파일 업로드</a> &gt; 예제 8</div>
		<div id="MainCenter">
			<article>	
				<div class="exTit">예제 8. 폼 요소 자동추가, 사용자 폼 요소 추가/삭제</div>
				<dl>
					<dt>설명</dt>
					<dd>
						<p>DEXTUploadNX는 기본적으로 화면상의 모든 input, select, textarea 요소들을 업로드 시점에 함께 전달합니다.</p>
						<p>만일 자동으로 전달되는 이 기능을 활성화하고 싶지 않다면 EnableAutoIncludeWebFormItems 속성 값을 false로 지정하면 됩니다.</p>
						<p>또한 DEXTUploadNX는 업로드할 파일이 없는 경우 폼 데이터를 전달하지 않습니다.</p>
						<p>파일이 없더라도 전송을 해야 하는 경우에는 EnableUploadFilesNotExist 속성 값을 true로 설정하면, 파일이 없더라도 서버로 요청을 시도합니다.</p>
						
						<pre class="prettyprint">
CreateDEXTUploadNX_Operator({
  ...
  // 기본값은 true이며, false로 지정하는 경우 폼 요소를 자동으로 전달하지 않습니다.
  EnableAutoIncludeWebFormItems: true,
  // 파일이 없는 경우라도 서버 요청을 수행하려면 true로 지정되어야 합니다.
  // 이 때 화면 상의 폼 요소들은 모두 전달이 됩니다.
  EnableUploadFilesNotExist: true,
  NXEventFunctions: {
    ...
  }
});</pre>
						<p>사용자 폼이란 HTML 코드 상에 명시된 input, select, textarea가 아닌 스크립트 수준에서 추가되는 폼 요소를 말합니다.</p>
						<p>User Data와 사용자 폼이 다른 점은, User Data는 파일 당 1개씩 등록이 되며, 사용자 폼은 파일과 상관없이 등록이 됩니다.</p>
						<p>더불어 User Data는 'DEXTUploadNX_UserData' 이름으로 전달되는 반면, 사용자 폼은 등록한 이름 그대로 서버에 전달됩니다.</p>
						<pre class="prettyprint">
// 사용자 폼을 추가합니다.
dextnxObj.AddUpItemUserForm(이름, 값);

// 사용자 폼을 삭제하려면
dextnxObj.DeleteFormItem(이름);

// 등록된 사용자 폼을 스크립트 상에서 확인하려면
// 주의) dextnxObj.Item(...) 메소드로 폼 데이터를 가져오지 못합니다.
var item = dextnxObj.UpItems.GetIndexItem(i);
if (item.ItemType == "USER_FORM") {
  alert("이름=" + item.FormName + ", 값 = " + item.FormValue;
}</pre> 
						<p>다음은 서버 측 코드에서 데이터를 처리하는 방법입니다.</p>   
						<pre class="prettyprint">
Enumeration&lt;String&gt; pNames = (Enumeration&lt;String&gt;)request.getParameterNames();
while (pNames.hasMoreElements()) {
  paramName = pNames.nextElement();
  // DEXTUploadNX로 시작하는 폼 이름을 제외한 나머지
  if (!paramName.startsWith("DEXTUploadNX")) {
    strValues = request.getParameterValues(paramName);
  }
}</pre>
					</dd>
					<dt>과정</dt>
					<dd>
						<div class="diagrambg">
							<div class="diagram-upload-flow">
								<a class="shape"><span class="head">Page</span><span class="target">upload/example.do?index=0008</span><span class="comment">예제 화면</span></a>
								<a class="direction"><img src="${contextPath}/common/images/arrow01.gif" alt="화살표"/><span class="comment">Post</span></a>					
								<a class="shape"><span class="head">FileServiceController</span><span class="target">service/formupload.do</span><span class="comment">전송 처리</span></a>
							</div>
						</div>
					</dd>			
					<dt>예제</dt>
					<dd>						
						<div id="dextnx_container" style="width:500px;height:300px;"></div>
						<p>&nbsp;</p>
						<p>
							<input type="button" value="파일 다이얼로그" onclick="showFileDialog();"/>
						</p>
						<p>&nbsp;</p>
						<p>사용자 폼(이름=값)을 추가합니다.</p>
						<p>
							사용자 폼 이름: <input type="text" id="txtUserFormName"/>
							사용자 폼 값: <input type="text" id="txtUserFormValue"/>
							<input type="button" value="사용자 폼 추가" onclick="addUserForm();"/>
						</p>
						<p>&nbsp;</p>
						<p>현재 컴포넌트에 추가된 모든 사용자 폼 데이터 확인합니다.</p>
						<p>
							<input type="button" value="사용자 폼 데이터 확인" onclick="showAllUserForms();"/>
						</p>
						<p>&nbsp;</p>
						<p>사용자 폼(이름=값) 값을 가져오거나 폼을 삭제합니다.</p>
						<p>
							폼 이름: <input type="text" id="txtGetUserFormName"/>
							<input type="button" value="폼 값 가져오기" onclick="getUserFormValue();"/>
							폼 이름: <input type="text" id="txtDeleteUserFormName"/>
							<input type="button" value="폼 삭제하기" onclick="deleteUserForm();"/>
						</p>
						<p>&nbsp;</p>
						<p>백엔드 제한: 개별 파일이 300MB가 넘거나, 전체 파일의 크기가 500MB가 넘는다면 업로드가 실패(오류발생)합니다.</p>
						<p>백엔드 제한: jpg,gif,png,doc,xls,ppt,docx,xlsx,pptx,pdf,txt,zip,7z,hwp  만 허용합니다.</p>
						<p>
							<input type="button" value="업로드 시작" onclick="uploadFiles();"/>
							<input type="button" value="업로드 중지" onclick="stopUploading();"/>
						</p>
					</dd>
				</dl>
			</article>
		</div>
	  <footer>
	    <div>Copyright ⓒ (주) 데브피아. All rights reserved.</div>
	  </footer>
	</div>
</body>
</html>