<%@ page language="java" contentType="text/html; charset=UTF-8" pageEncoding="UTF-8"%>
<% request.setAttribute("contextPath", request.getContextPath()); %>
<!DOCTYPE html>
<html>
<head>
	<meta charset="UTF-8"/>
	<meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
	<title>DEXTUpload(NX+NJ) Samples</title>
	<link rel="stylesheet" href="${contextPath}/common/styles/default.css"/>
	<link rel="stylesheet" href="${contextPath}/common/js/prettify/tomorrow.css"/>
	<script src="${contextPath}/common/js/prettify/prettify.js"></script>
	<script src="${contextPath}/dextuploadnx/DEXTUploadNX.js"></script>
	<script>
		var promptForAdding = true;
		
		window.onload = function () {
			prettyPrint();
			
			CreateDEXTUploadNX_Operator({
				ContainerID: "dextnx_container",
				ElementID: "dextnx",
				Operator_Type: "UPLOAD_MANAGER",	
				ExtractEXIF: true,
				NXEventFunctions: {
					OnNXOperatorEventError: function (id, optype, err) {
						NXAlert(id, "컴포넌트ID:" + id + "\n오류메시지:\n" + err);
					},
					OnNXOperatorEventCreateComplete: function (id, optype) {
						NXAlert(id, "DEXTUploadNX가 로드되었습니다.");
					},
					OnNXOperatorEventUploadStartTotal: function (id, optype) {
						NXAlert(id, "업로드를 시작합니다.");
					},
					OnNXOperatorEventUploadCompleteTotal: function (id, optype) {
					    var resObj = NXOperators[id].Responses;
					    var responseData = "";
					    for (var i = 0; i < resObj.Count; i++) {
					        responseData += (i == 0) ? resObj.Item(i) : "\n" + resObj.Item(i);
					    }
					    
					    NXAlert(id, "업로드가 완료되었습니다.\n\n서버로부터 받은 응답 데이터\n" + responseData);
					},
					OnNXOperatorEventUploadCancel: function (id, optype) {
						NXAlert(id, "업로드가 중지되었습니다.");
					}
				}
			});
		};
		
		function showFileDialog() {
			NXOperators["dextnx"].OpenFileDialog();
		}
		
		function uploadFiles() {
			NXOperators["dextnx"].UploadURL = "http://" + location.host + "/sample.nxnj/service/exifupload.do";
			NXOperators["dextnx"].UploadStart();
		}
		
		function stopUploading() {
			NXOperators["dextnx"].UploadStop();
		}
		
		function showExif() {
			var size = NXOperators["dextnx"].UpItems.Count;
			var strSplit = NXOperators["dextnx"].DEXTNX_Split_Str;
			var strEmpty = NXOperators["dextnx"].DEXTNX_Empty_Str;
			var exif = "";
			
			for (var i = 0; i < size; i++) {
				if (NXOperators["dextnx"].IsSelectedItem(i) == true) {
					var item = NXOperators["dextnx"].UpItems.GetIndexItem(i);
					var tokens = item.EXIFData.split(strSplit);
					
					for (var j = 0; j < tokens.length - 1; j+=2) {
						if (j < (tokens.length - 1) && tokens[j + 1] == strEmpty)
							exif += tokens[j] + "=\n";
						else
							exif += tokens[j] + "=" + tokens[j + 1] + "\n";
					}
					
					alert(exif);
					
					return;
				}
			}
			
			alert("파일이 없거나 선택된 항목이 없습니다.");
		}
	</script>
</head>
<body>
	<div id="Container">
		<header><div class="logobg"></div></header>
		<div id="root"><a href="${contextPath}">DEXTUpload<span class="f_point">(NX+NJ)</span> Samples</a> &gt; <a href="${contextPath}/#tlb-upload">파일 업로드</a> &gt; 예제 9</div>
		<div id="MainCenter">
			<article>	
				<div class="exTit">예제 9. 이미지 파일 EXIF 데이터 처리</div>
				<dl>
					<dt>설명</dt>
					<dd>
						<p>업로드할 파일이 EXIF를 지원하는 경우 EXIF 데이터를 서버로 따로 전달할 수 있습니다.</p>
						<p>EXIF 데이터에 대하여 아래 링크에서 정보를 확인 할 수 있습니다.</p>
						<p><a href="http://msdn.microsoft.com/en-us/library/ms534416(v=vs.85).aspx" target="_blank" style="text-decoration:none">EXIF Data PropertyTag 이동</a></p>
						<pre class="prettyprint">
CreateDEXTUploadNX_Operator({
  ...
  // EXIF 데이터를 전달토록 설정합니다.
  ExtractEXIF: true,
  NXEventFunctions: {
    ...
  }
});</pre>				
						<pre class="prettyprint">
// 등록된 사용자 폼을 스크립트 상에서 확인하려면 
var item = dextnxObj.UpItems.GetIndexItem(i);
// EXIF 데이터는 다음과 같은 형식으로 설정됩니다.
// a[SPLIT]123[SPLIT]b[SPLIT][EMPTY]c[SPLIT]QWE[SPLIT]
alert(item.EXIFData);
</pre> 
						<p>다음은 서버 측 코드에서 데이터를 처리하는 방법입니다.</p>   
						<pre class="prettyprint">
for (int i = 0; i &lt; nx.getFiles().size(); i++) {
  // DEXTUploadNX는 'DEXTUploadNX_ExifData' 이름으로 각 파일의 EXIF를 서버로 전달합니다.
  // DEXTUploadNXRequest 객체의 getExifData 메소드로부터 정보를 얻습니다.
  exif = nx.getExifData();
}</pre>
					</dd>
					<dt>과정</dt>
					<dd>
						<div class="diagrambg">
							<div class="diagram-upload-flow">
								<a class="shape"><span class="head">Page</span><span class="target">upload/example.do?index=0009</span><span class="comment">예제 화면</span></a>
								<a class="direction"><img src="${contextPath}/common/images/arrow01.gif" alt="화살표"/><span class="comment">Post</span></a>					
								<a class="shape"><span class="head">FileServiceController</span><span class="target">service/exifupload.do</span><span class="comment">전송 처리</span></a>
							</div>
						</div>
					</dd>			
					<dt>예제</dt>
					<dd>						
						<div id="dextnx_container" style="width:500px;height:300px;"></div>
						<p>&nbsp;</p>
						<p>EXIF 정보를 확인하려면 jpeg만 등록해야 합니다.</p>
						<p>
							<input type="button" value="파일 다이얼로그" onclick="showFileDialog();"/>
						</p>						
						<p>&nbsp;</p>
						<p>현재 선택된 파일의 EXIF 정보를 확인합니다.</p>
						<p>
							<input type="button" value="선택된 파일의 EXIF 데이터 확인" onclick="showExif();"/>
						</p>
						<p>&nbsp;</p>
						<p>백엔드 제한: 개별 파일이 300MB가 넘거나, 전체 파일의 크기가 500MB가 넘는다면 업로드가 실패(오류발생)합니다.</p>
						<p>백엔드 제한: jpg,gif,png,doc,xls,ppt,docx,xlsx,pptx,pdf,txt,zip,7z,hwp  만 허용합니다.</p>
						<p>
							<input type="button" value="업로드 시작" onclick="uploadFiles();"/>
							<input type="button" value="업로드 중지" onclick="stopUploading();"/>
						</p>
					</dd>
				</dl>
			</article>
		</div>
	  <footer>
	    <div>Copyright ⓒ (주) 데브피아. All rights reserved.</div>
	  </footer>
	</div>
</body>
</html>