<%@ page language="java" contentType="text/html; charset=UTF-8" pageEncoding="UTF-8"%>
<% request.setAttribute("contextPath", request.getContextPath()); %>
<!DOCTYPE html>
<html>
<head>
	<meta charset="UTF-8"/>
	<meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
	<title>DEXTUpload(NX+NJ) Samples</title>
	<link rel="stylesheet" href="${contextPath}/common/styles/default.css"/>
	<link rel="stylesheet" href="${contextPath}/common/js/prettify/tomorrow.css"/>
	<script src="${contextPath}/common/js/prettify/prettify.js"></script>
	<script src="${contextPath}/dextuploadnx/DEXTUploadNX.js"></script>
	<script>
		var promptForAdding = true;
		
		window.onload = function () {
			prettyPrint();
			
			CreateDEXTUploadNX_Operator({
				ContainerID: "dextnx_container",
				ElementID: "dextnx",
				Operator_Type: "UPLOAD_MANAGER",
				UploadMode: "OROF",
				NXEventFunctions: {
					OnNXOperatorEventError: function (id, optype, err) {
						NXAlert(id, "컴포넌트ID:" + id + "\n오류메시지:\n" + err);
					},
					OnNXOperatorEventCreateComplete: function (id, optype) {
						NXAlert(id, "DEXTUploadNX가 로드되었습니다.");
					},
					OnNXOperatorEventUploadStartTotal: function (id, optype) {
						NXAlert(id, "업로드를 시작합니다.");
					},
					OnNXOperatorEventUploadCompleteTotal: function (id, optype) {
					    var resObj = NXOperators[id].Responses;
					    var responseData = "";
					    for (var i = 0; i < resObj.Count; i++) {
					        responseData += (i == 0) ? resObj.Item(i) : "\n" + resObj.Item(i);
					    }
					    
					    NXAlert(id, "업로드가 완료되었습니다.\n\n서버로부터 받은 응답 데이터\n" + responseData);
					},
					OnNXOperatorEventUploadCancel: function (id, optype) {
						NXAlert(id, "업로드가 중지되었습니다.");
					}
				}
			});
		};
		
		function showFileDialog() {
			NXOperators["dextnx"].OpenFileDialog();
		}
		
		function uploadFiles() {
			NXOperators["dextnx"].UploadURL = "http://" + location.host + "/sample.nxnj/service/orofupload.do";
			NXOperators["dextnx"].UploadStart();
		}
		
		function stopUploading() {
			NXOperators["dextnx"].UploadStop();
		}
	</script>
</head>
<body>
	<div id="Container">
		<header><div class="logobg"></div></header>
		<div id="root"><a href="${contextPath}">DEXTUpload<span class="f_point">(NX+NJ)</span> Samples</a> &gt; <a href="${contextPath}/#tlb-upload">파일 업로드</a> &gt; 예제 12</div>
		<div id="MainCenter">
			<article>	
				<div class="exTit">예제 12. OROF 파일 업로드</div>
				<dl>
					<dt>설명</dt>
					<dd>
						<p>DEXTUploadNX는 일반적으로 ORAF 모드로 파일 업로드를 수행합니다.</p>
						<ul class="notice">
							<li>ORAF: 하나의 요청(서버로)에 업로드할 모든 파일과 여러 데이터가 포함된 업로드 방식입니다.</li>
							<li>OROF: 파일의 개수 및 여러 메타 데이터를 분리하여 서버로 요청(다수)합니다.</li>
						</ul>
						<p>&nbsp;</p>
						<p>OROF 모드로 설정이 된 경우, 업로드 아이템의 갯수만큼 요청이 발생합니다.</p>
						<p>예를 들어 파일이 10개인 경우, 10(업로드할 개수) + 1(사용자 폼 데이터, 가상 파일 데이터, 삭제된 가상 파일 데이터, 빈 폴더 데이터) = 총 11번의 요청이 발생합니다.</p>
						<p>OROF 모드는 한 번의 요청에 1개의 파일이 처리되므로 파일 전체 크기에 대한 제한을 받지 않습니다.</p>
						<pre class="prettyprint">
CreateDEXTUploadNX_Operator({
  ...
  // OROF 모드로 설정합니다.
  UploadMode: "OROF",
  NXEventFunctions: {
    ...
  }
});</pre>
						<p>서버로 요청이 여러번 발생하기 때문에 응답 데이터는 요청 수만큼 발생합니다.</p>
						<pre class="prettyprint">
OnNXOperatorEventUploadCompleteTotal: function (id, optype) {
  var resObj = NXOperators[id].Responses;
  var responseData = "";
  // ORAF에서는 resObj.Count값은 항상 1입니다.
  // 그러나 OROF에서는 서버로 요청한 수만큼 설정됩니다.
  for (var i = 0; i &lt; resObj.Count; i++) {
    responseData += (i == 0) ? resObj.Item(i) : "\n" + resObj.Item(i);
  }
    
  NXAlert(id, "업로드가 완료되었습니다.\n\n서버로부터 받은 응답 데이터\n" + responseData);
}</pre>
						<p>다음은 서버 측 코드에서 데이터를 처리하는 방법입니다.</p>   
						<pre class="prettyprint">
if (nx.hasFiles()) {
  // 파일이 존재하는 경우이며 파일의 개수만큼 코드를 수행할 것입니다.
  item = (FileItem)nx.getFiles().get(0);
  if (item.isEligibleFile()) {
    item.save();
  }
} else {
  // 파일이 없는 경우에는 DEXTUploadNX에서 마지막 요청을 한 것입니다.
  // HTML 폼 및 사용자 폼 데이터를 처리합니다.
  // 가상 파일 처리는 여기서 처리합니다.
  // 삭제된 가상 파일은 여기서 처리합니다.
  // 빈 폴더 처리를 수행합니다.
}</pre>
					</dd>
					<dt>과정</dt>
					<dd>
						<div class="diagrambg">
							<div class="diagram-upload-flow">
								<a class="shape"><span class="head">Page</span><span class="target">upload/example.do?index=0012</span><span class="comment">예제 화면</span></a>
								<a class="direction"><img src="${contextPath}/common/images/arrow01.gif" alt="화살표"/><span class="comment">Post(N + 1)</span></a>					
								<a class="shape"><span class="head">FileServiceController</span><span class="target">service/orofupload.do</span><span class="comment">전송 처리</span></a>
							</div>
						</div>
					</dd>
					<dt>예제</dt>
					<dd>						
						<div id="dextnx_container" style="width:500px;height:300px;"></div>
						<p>&nbsp;</p>
						<p>
							<input type="button" value="파일 다이얼로그" onclick="showFileDialog();"/>
						</p>
						<p>&nbsp;</p>
						<p>백엔드 제한: 개별 파일이 300MB가 넘거나, 전체 파일의 크기가 500MB가 넘는다면 업로드가 실패(오류발생)합니다.</p>
						<p>백엔드 제한: jpg,gif,png,doc,xls,ppt,docx,xlsx,pptx,pdf,txt,zip,7z,hwp  만 허용합니다.</p>
						<p>
							<input type="button" value="업로드 시작" onclick="uploadFiles();"/>
							<input type="button" value="업로드 중지" onclick="stopUploading();"/>
						</p>
					</dd>
				</dl>
			</article>
		</div>
	  <footer>
	    <div>Copyright ⓒ (주) 데브피아. All rights reserved.</div>
	  </footer>
	</div>
</body>
</html>