<%@ page language="java" contentType="text/html; charset=UTF-8" pageEncoding="UTF-8"%>
<% request.setAttribute("contextPath", request.getContextPath()); %>
<!DOCTYPE html>
<html>
<head>
	<meta charset="UTF-8"/>
	<meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
	<title>DEXTUpload(NX+NJ) Samples</title>
	<link rel="stylesheet" href="${contextPath}/common/styles/default.css"/>
	<link rel="stylesheet" href="${contextPath}/common/js/prettify/tomorrow.css"/>
	<script src="${contextPath}/common/js/prettify/prettify.js"></script>
	<script src="${contextPath}/dextuploadnx/DEXTUploadNX.js"></script>
	<script>		
		window.onload = function () {
			prettyPrint();
			
			CreateDEXTUploadNX_Operator({
				ContainerID: "dextnx_container",
				ElementID: "dextnx",
				Operator_Type: "UPLOAD_MANAGER",
				NXEventFunctions: {
					OnNXOperatorEventError: function (id, optype, err) {
						NXAlert(id, "컴포넌트ID:" + id + "\n오류메시지:\n" + err);
					},
					OnNXOperatorEventCreateComplete: function (id, optype) {
						NXAlert(id, "DEXTUploadNX가 로드되었습니다.");
					}
				}
			});
		};
		
		function showFileDialog() {
			NXOperators["dextnx"].OpenFileDialog();
		}
		
		function showFolderDialog() {
			NXOperators["dextnx"].OpenFolderDialog();
		}
		
		function toggleSilence(enable) {
			NXOperators["dextnx"].UpFilteringCheckInSilence = enable;
		}
		
		function toggleExtFilter(method) {
			if (method == "W") {
				document.getElementById("txtWExtFilterValue").disabled = null;
				document.getElementById("btnSetWExtFilter").disabled = null;
				document.getElementById("txtBExtFilterValue").disabled = "disabled";
				document.getElementById("btnSetBExtFilter").disabled = "disabled";
			} else if (method == "B") {
				document.getElementById("txtWExtFilterValue").disabled = "disabled";
				document.getElementById("btnSetWExtFilter").disabled = "disabled";
				document.getElementById("txtBExtFilterValue").disabled = null;
				document.getElementById("btnSetBExtFilter").disabled = null;
			}
		}
		
		function setWhiteExtensionFilter() {
			NXOperators["dextnx"].FilterWhite = document.getElementById("txtWExtFilterValue").value;
			NXOperators["dextnx"].FilterBlack = "";
		}
		
		function setBlackExtensionFilter() {
			NXOperators["dextnx"].FilterWhite = "";
			NXOperators["dextnx"].FilterBlack = document.getElementById("txtBExtFilterValue").value;
		}
		
		function setFileCountFilter() {
			var cnt = document.getElementById("cboLimitFileCount").value;
			NXOperators["dextnx"].LimitUpFileCount = parseInt(cnt);
		}
		
		function setFileSizeFilter() {
			var size = document.getElementById("cboLimitFileSize").value;
			NXOperators["dextnx"].LimitUpFileSize = parseInt(size);
		}
		
		function setFileTotalSizeFilter() {
			var total = document.getElementById("cboLimitTotalFileSize").value;
			NXOperators["dextnx"].LimitUpTotalFileSize = parseInt(total);
		}
	</script>
</head>
<body>
	<div id="Container">
		<header><div class="logobg"></div></header>
		<div id="root"><a href="${contextPath}">DEXTUpload<span class="f_point">(NX+NJ)</span> Samples</a> &gt; <a href="${contextPath}/#tlb-upload">파일 업로드</a> &gt; 예제 18</div>
		<div id="MainCenter">
			<article>
				<div class="exTit">예제 18. 확장자, 파일 개수, 파일 크기 필터링</div>
				<dl>
					<dt>설명</dt>
					<dd>						
						<p>DEXTUploadNX는 업로드할 파일을 제한하는 필터링 기능을 제공합니다.</p>
						<pre class="prettyprint">
CreateDEXTUploadNX_Operator({
  ...
  // 등록이 가능한 확장자만을 설정합니다.
  FilterWhite: "이미지파일(jpg,jpeg,gif,bmp)|*.jpg;*.jpeg;*.gif;*.bmp;|문서파일(txt)|*.txt;*||",
  // 등록이 불가능한 확장자만을 설정합니다.
  FilterBlack: "*.ppt;*.xls;*.html",
  // 위의 두 확장자 필터를 함께 설정하지 마십시오.
  
  // 등록이 가능한 파일의 개수를 설정합니다.
  LimitUpFileCount: 100,
  // 등록이 가능한 파일의 크기를 설정합니다.
  LimitUpFileSize: (1024 * 1024 * 10),
  // 등록이 가능한 파일의 전체 크기를 설정합니다.
  LimitUpTotalFileSize: (1024 * 1024 * 100),
  ...  
  // UpFilteringCheckInSilence 속성값이 true이면 필터링 대상이 발견되어도
  // 이벤트 발생없이 내부적으로 정리를 수행합니다.
  UpFilteringCheckInSilence: true;
  ...
  NXEventFunctions: {
    ...
  }
});</pre>
					</dd>					
					<dt>예제</dt>
					<dd>						
						<div id="dextnx_container" style="width:500px;height:300px;"></div>
						<p>&nbsp;</p>
						<p>
							<input type="button" value="파일 다이얼로그" onclick="showFileDialog();"/>
							<input type="button" value="폴더 다이얼로그" onclick="showFolderDialog();"/>
						</p>
						<p>&nbsp;</p>
						<p>필터 대상이 발견되었을 때, 이벤트가 발생할지 아니면 내부적으로 자동정리할지 결정할 수 있습니다.</p>
						<p>
							<input type="radio" name="rdoSilence" onclick="toggleSilence(true);"/><label>자동정리</label>
							<input type="radio" name="rdoSilence" onclick="toggleSilence(false);" checked="checked"/><label>이벤트발생(기본값)</label>
						</p>
						<p>&nbsp;</p> 
						<p>확장자 필터링을 설정합니다.</p>
						<p>확장자 필터링은 white 방식과 black 방식이 있습니다.</p>
						<p>white인 경우는 등록을 허용할 파일 확장자를 지정하는 방식이며, black의 경우는 등록을 거부할 확장자를 지정하는 방식입니다.</p>
						<p>두 가지 방식은 논리적으로 함께 사용할 수 없으므로, 확장자 필터링은 하나만 사용해야 합니다.</p>
						<p>일반적으로 보안성을 높히기 위해서 white 방식만을 사용합니다.</p>
						<p>
							<input type="radio" name="rdoWorB" onclick="toggleExtFilter('W');" checked="checked"/><label>White 방식</label>
							<input type="radio" name="rdoWorB" onclick="toggleExtFilter('B');"/><label>Black 방식(역필터라고도 합니다.)</label>
						</p>
						<p>							
							White 필터 값
							<input type="text" id="txtWExtFilterValue" style="width:300px;" value="이미지파일(jpg,jpeg,gif,bmp)|*.jpg;*.jpeg;*.gif;*.bmp;|문서파일(txt)|*.txt;*||"/>
							<input type="button" id="btnSetWExtFilter" value="확장자 필터 설정" onclick="setWhiteExtensionFilter();"/>
						</p>
						<p>							
							Black 필터 값
							<input type="text" id="txtBExtFilterValue" style="width:300px;" value="*.ppt;*.xls;*.html" disabled="disabled"/>
							<input type="button" id="btnSetBExtFilter" value="확장자 필터 설정" onclick="setBlackExtensionFilter();" disabled="disabled"/>
						</p>
						<p>&nbsp;</p>
						<p>파일의 개수를 제한합니다.</p>
						<p>
							<select id="cboLimitFileCount">
								<option value="0">없음</option>
								<option value="1">1개</option>
								<option value="2">2개</option>
								<option value="3">3개</option>
								<option value="4">4개</option>
								<option value="5">5개</option>
							</select>
							<input type="button" value="파일 개수 제한 설정" onclick="setFileCountFilter();"/>
						</p>
						<p>&nbsp;</p>
						<p>파일의 크기(개별)를 제한합니다.</p>
						<p>
							<select id="cboLimitFileSize">
								<option value="0">없음</option>
								<option value="1048576">1MB</option>
								<option value="5242880">5MB</option>
								<option value="10485760">10MB</option>
								<option value="104857600">100MB</option>
								<option value="1073741824">1GB</option>
							</select>
							<input type="button" value="파일 크기 제한 설정" onclick="setFileSizeFilter();"/>
						</p>
						<p>&nbsp;</p>
						<p>전체 파일의 크기를 제한합니다.</p>
						<p>
							<select id="cboLimitTotalFileSize">
								<option value="0">없음</option>
								<option value="5242880">5MB</option>
								<option value="10485760">10MB</option>
								<option value="104857600">100MB</option>
								<option value="1073741824">1GB</option>
							</select>
							<input type="button" value="전체 파일 크기 제한 설정" onclick="setFileTotalSizeFilter();"/>
						</p>
					</dd>
				</dl>
			</article>
		</div>
	  <footer>
	    <div>Copyright ⓒ (주) 데브피아. All rights reserved.</div>
	  </footer>
	</div>
</body>
</html>