<%@ page language="java" contentType="text/html; charset=UTF-8" pageEncoding="UTF-8"%>
<% request.setAttribute("contextPath", request.getContextPath()); %>
<!DOCTYPE html>
<html>
<head>
	<meta charset="UTF-8"/>
	<meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
	<title>DEXTUpload(NX+NJ) Samples</title>
	<link rel="stylesheet" href="${contextPath}/common/styles/default.css"/>
	<link rel="stylesheet" href="${contextPath}/common/js/prettify/tomorrow.css"/>
	<script src="${contextPath}/common/js/prettify/prettify.js"></script>
	<script src="${contextPath}/dextuploadnx/DEXTUploadNX.js"></script>
	<script>
		var promptForAdding = true;
		
		window.onload = function () {
			prettyPrint();
			
			CreateDEXTUploadNX_Operator({
				ContainerID: "dextnx_container",
				ElementID: "dextnx",
				Operator_Type: "UPLOAD_MANAGER",				
				NXEventFunctions: {
					OnNXOperatorEventError: function (id, optype, err) {
						NXAlert(id, "컴포넌트ID:" + id + "\n오류메시지:\n" + err);
					},
					OnNXOperatorEventCreateComplete: function (id, optype) {
						NXAlert(id, "DEXTUploadNX가 로드되었습니다.");
					},
					OnNXOperatorEventUploadStartTotal: function (id, optype) {
						NXAlert(id, "업로드를 시작합니다.");
					},
					OnNXOperatorEventUploadCompleteTotal: function (id, optype) {
					    var resObj = NXOperators[id].Responses;
					    var responseData = "";
					    for (var i = 0; i < resObj.Count; i++) {
					        responseData += (i == 0) ? resObj.Item(i) : "\n" + resObj.Item(i);
					    }
					    
					    NXAlert(id, "업로드가 완료되었습니다.\n\n서버로부터 받은 응답 데이터\n" + responseData);
					},
					OnNXOperatorEventUploadCancel: function (id, optype) {
						NXAlert(id, "업로드가 중지되었습니다.");
					}
				}
			});
		};
		
		function showFileDialog() {
			NXOperators["dextnx"].OpenFileDialog();
		}
		
		function uploadFiles() {
			NXOperators["dextnx"].UploadURL = "http://" + location.host + "/sample.nxnj/service/aliasupload.do";
			NXOperators["dextnx"].UploadStart();
		}
		
		function stopUploading() {
			NXOperators["dextnx"].UploadStop();
		}
		
		function setAlias() {
			var index = document.getElementById("txtFileIndex").value;
			var value = document.getElementById("txtAliasValue").value;
			
			if (!index || isNaN(index)) {
				alert("파일의 인덱스(0부터 시작)를 올바르게 입력하세요.");
			} else {
				NXOperators["dextnx"].SetUpFileItemAlias(parseInt(index), value);
				document.getElementById("txtFileIndex").value = "";
				document.getElementById("txtAliasValue").value = "";
			}
		}
		
		function showAlias() {
			var size = NXOperators["dextnx"].UpItems.Count;
			
			for (var i = 0; i < size; i++) {
				if (NXOperators["dextnx"].IsSelectedItem(i) == true) {
					var item = NXOperators["dextnx"].Item(i);
					alert(item.Alias);
					
					return;
				}
			}
			
			alert("파일이 없거나 선택된 항목이 없습니다.");
		}
	</script>
</head>
<body>
	<div id="Container">
		<header><div class="logobg"></div></header>
		<div id="root"><a href="${contextPath}">DEXTUpload<span class="f_point">(NX+NJ)</span> Samples</a> &gt; <a href="${contextPath}/#tlb-upload">파일 업로드</a> &gt; 예제 30</div>
		<div id="MainCenter">
			<article>	
				<div class="exTit">예제 30. 업로드 파일 별칭 정의</div>
				<dl>
					<dt>설명</dt>
					<dd>
						<p>업로드 되는 파일마다 별칭을 함께 실어 보낼 수 있습니다.</p>
						<p>별칭은 파일 하나당 1개만 설정이 가능하며, 사용자 데이타와는 다릅니다.</p>
						<pre class="prettyprint">
// 업로드할 파일의 순서에 별칭을 설정합니다.
dextnxObj.SetUpFileItemAlias(파일인덱스값, 값);

// 별칭을 스크립트 상에서 확인하려면 
var item = dextnxObj.UpItems.GetIndexItem(i);
var alias = item.Alias;</pre> 
						<p>다음은 서버 측 코드에서 데이터를 처리하는 방법입니다.</p>   
						<pre class="prettyprint">
for (int i = 0; i &lt; nx.getFiles().size(); i++) {
  // DEXTUploadNX는 'DEXTUploadNX_Alias' 이름으로 각 파일의 별칭을 서버로 전달합니다.
  // DEXTUploadNXRequest 객체의 getAliases 메소드로부터 정보를 얻습니다.
  alias = nx.getAliases().get(i);
}</pre>
					</dd>
					<dt>과정</dt>
					<dd>
						<div class="diagrambg">
							<div class="diagram-upload-flow">
								<a class="shape"><span class="head">Page</span><span class="target">upload/example.do?index=0030</span><span class="comment">예제 화면</span></a>
								<a class="direction"><img src="${contextPath}/common/images/arrow01.gif" alt="화살표"/><span class="comment">Post</span></a>					
								<a class="shape"><span class="head">FileServiceController</span><span class="target">service/aliasupload.do</span><span class="comment">전송 처리</span></a>
							</div>
						</div>
					</dd>			
					<dt>예제</dt>
					<dd>						
						<div id="dextnx_container" style="width:500px;height:300px;"></div>
						<p>&nbsp;</p>
						<p>파일 먼저 추가한 후 별칭을 설정할 수 있습니다.</p>
						<p>
							<input type="button" value="파일 다이얼로그" onclick="showFileDialog();"/>
						</p>
						<p>&nbsp;</p>
						<p>주어진 순서에 해당하는 파일의 별칭을 설정합니다.</p>
						<p>
							파일 인덱스: <input type="text" id="txtFileIndex"/>
							사용자 데이터 값: <input type="text" id="txtAliasValue"/>
							<input type="button" value="별칭 설정" onclick="setAlias();"/>
						</p>
						<p>&nbsp;</p>
						<p>파일 리스트에서 현재 선택된 파일의 별칭을 확인합니다.</p>
						<p>
							<input type="button" value="선택된 파일의 별칭 확인" onclick="showAlias();"/>
						</p>
						<p>&nbsp;</p>
						<p>백엔드 제한: 개별 파일이 300MB가 넘거나, 전체 파일의 크기가 500MB가 넘는다면 업로드가 실패(오류발생)합니다.</p>
						<p>백엔드 제한: jpg,gif,png,doc,xls,ppt,docx,xlsx,pptx,pdf,txt,zip,7z,hwp  만 허용합니다.</p>
						<p>
							<input type="button" value="업로드 시작" onclick="uploadFiles();"/>
							<input type="button" value="업로드 중지" onclick="stopUploading();"/>
						</p>
					</dd>
				</dl>
			</article>
		</div>
	  <footer>
	    <div>Copyright ⓒ (주) 데브피아. All rights reserved.</div>
	  </footer>
	</div>
</body>
</html>